==> haskell-rio-orphans-0.1.2.0-477-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-JpCWrIj6mNuDRIESIf4PHw
key:                  rio-orphans-0.1.2.0-JpCWrIj6mNuDRIESIf4PHw
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  b87da961333c147c76a56239bf4ff842
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-JpCWrIj6mNuDRIESIf4PHw
depends:
    base-4.18.2.1 exceptions-0.10.7
    fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    rio-0.1.22.0-9YWPFaDDA8QAvZjRU1ibSo
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.2.0-478-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-8jNTzwGCeuh9kbO21QidXm
key:                  rio-orphans-0.1.2.0-8jNTzwGCeuh9kbO21QidXm
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  6a5b9b1e31710a2b29fe03e5cf65a5a5
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-8jNTzwGCeuh9kbO21QidXm
depends:
    base-4.18.2.1 exceptions-0.10.7
    fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    rio-0.1.24.0-FBO4PrA6UlqFqVtMb3OxSz
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
